@@ -161,6 +161,7 @@ static void giop_connection_init(GIOPConnection *giop_connection,
   giop_connection->refcount = 0;
   giop_connection->connection_class = cnxclass;
   giop_connection->is_valid = FALSE;
+  giop_connection->is_auth = FALSE;
   giop_connection->was_initiated = FALSE;
 }
 
@@ -464,7 +465,10 @@ iiop_connection_from_fd(int fd, IIOPConnection *parent)
 
   fcntl(GIOP_CONNECTION_GET_FD(fd_cnx), F_SETFD,
 	fcntl(GIOP_CONNECTION_GET_FD(fd_cnx), F_GETFD, 0)
-	| FD_CLOEXEC | O_NONBLOCK);
+	| FD_CLOEXEC);
+  fcntl(GIOP_CONNECTION_GET_FD(fd_cnx), F_SETFL,
+	fcntl(GIOP_CONNECTION_GET_FD(fd_cnx), F_GETFL, 0)
+	| O_NONBLOCK);
 
   ORBit_Trace(TraceMod_IIOP, TraceLevel_Debug,
 	      "iiop_connection_from_fd connect [%d]\n",
@@ -507,8 +511,13 @@ iiop_connection_server(void)
        (struct sockaddr *)&server_cnx->u.ipv4.location,
        sizeof(struct sockaddr_in));
 
-  fcntl(GIOP_CONNECTION_GET_FD(server_cnx), F_SETFD, fcntl(GIOP_CONNECTION_GET_FD(server_cnx), F_GETFD, 0) | FD_CLOEXEC | O_NONBLOCK);
-  
+  fcntl(GIOP_CONNECTION_GET_FD(server_cnx), F_SETFD,
+	fcntl(GIOP_CONNECTION_GET_FD(server_cnx), F_GETFD, 0)
+	| FD_CLOEXEC);
+  fcntl(GIOP_CONNECTION_GET_FD(server_cnx), F_SETFL,
+	fcntl(GIOP_CONNECTION_GET_FD(server_cnx), F_GETFL, 0)
+	| O_NONBLOCK);
+
   n = sizeof(struct sockaddr_in);
   getsockname(GIOP_CONNECTION_GET_FD(server_cnx),
 	      (struct sockaddr *)&server_cnx->u.ipv4.location, &n);
@@ -579,7 +588,12 @@ iiop_connection_server_ipv6(void)
        (struct sockaddr *)&server_cnx->u.ipv6.location,
        sizeof(struct sockaddr_in6));
   
-  fcntl(GIOP_CONNECTION_GET_FD(server_cnx), F_SETFD, fcntl(GIOP_CONNECTION_GET_FD(server_cnx), F_GETFD, 0) | FD_CLOEXEC | O_NONBLOCK);
+  fcntl(GIOP_CONNECTION_GET_FD(server_cnx), F_SETFD,
+	fcntl(GIOP_CONNECTION_GET_FD(server_cnx), F_GETFD, 0)
+	| FD_CLOEXEC);
+  fcntl(GIOP_CONNECTION_GET_FD(server_cnx), F_SETFL,
+	fcntl(GIOP_CONNECTION_GET_FD(server_cnx), F_GETFL, 0)
+	| O_NONBLOCK);
 
   n = sizeof(struct sockaddr_in6);
   getsockname(GIOP_CONNECTION_GET_FD(server_cnx), &server_cnx->u.ipv6.location, &n);
@@ -659,7 +673,12 @@ iiop_connection_server_unix(const char *sockpath)
     goto failed;
   }
 
-  fcntl(GIOP_CONNECTION_GET_FD(server_cnx_unix), F_SETFD, fcntl(GIOP_CONNECTION_GET_FD(server_cnx_unix), F_GETFD, 0) | FD_CLOEXEC | O_NONBLOCK);
+  fcntl(GIOP_CONNECTION_GET_FD(server_cnx_unix), F_SETFD,
+	fcntl(GIOP_CONNECTION_GET_FD(server_cnx_unix), F_GETFD, 0)
+	| FD_CLOEXEC);
+  fcntl(GIOP_CONNECTION_GET_FD(server_cnx_unix), F_SETFL,
+	fcntl(GIOP_CONNECTION_GET_FD(server_cnx_unix), F_GETFL, 0)
+	| O_NONBLOCK);
 
   if(listen(GIOP_CONNECTION_GET_FD(server_cnx_unix), 5) != 0)
     goto failed;
@@ -830,6 +849,7 @@ iiop_connection_new(const char *host, gushort port)
 	      host, (guint)port);
 
   GIOP_CONNECTION(retval)->was_initiated = TRUE;
+  GIOP_CONNECTION(retval)->is_auth = TRUE;
 
   giop_connection_add_to_list(GIOP_CONNECTION(retval));
 
@@ -928,6 +948,7 @@ iiop_connection_unix_new(const char *sockpath)
   }
 
   GIOP_CONNECTION(retval)->was_initiated = TRUE;
+  GIOP_CONNECTION(retval)->is_auth = TRUE;
 
   giop_connection_add_to_list(GIOP_CONNECTION(retval));
 
@@ -1262,6 +1283,7 @@ giop_check_connections(gboolean block_for_reply)
   int pollret;
   int numcnx_checks;
   int i;
+  fd_set selectset_rd, selectset_ex;
 
 #ifndef USE_POLL
   struct timeval immediate_timeout = {0,0};
@@ -1271,8 +1293,15 @@ giop_check_connections(gboolean block_for_reply)
 
   if(!giop_connection_list.list)
     return NULL;
+#if 0
   giop_connection_list_recreate(); /* easiest way to get valid
 				      select sets... */
+#else
+  memcpy(&selectset_rd, &giop_connection_list.selectset_rd,
+	 sizeof(selectset_rd));
+  memcpy(&selectset_ex, &giop_connection_list.selectset_ex,
+	 sizeof(selectset_ex));
+#endif
 
 #ifdef USE_POLL
   numcnx_checks = giop_connection_list.pollset->len;
@@ -1288,10 +1317,12 @@ giop_check_connections(gboolean block_for_reply)
 
 #     else /* !USE_POLL */
 
-  pollret = select (giop_connection_list.max_fd + 1,
-		    &giop_connection_list.selectset_rd,
-		    NULL, &giop_connection_list.selectset_ex,
-		    block_for_reply?NULL:&immediate_timeout);
+  {
+    pollret = select (giop_connection_list.max_fd + 1,
+		      &selectset_rd,
+		      NULL, &selectset_ex,
+		      block_for_reply?NULL:&immediate_timeout);
+  }
 #     endif /* !USE_POLL */
 
   if(pollret <= 0) {
@@ -1320,7 +1351,7 @@ giop_check_connections(gboolean block_for_reply)
       goto got_connection;
 #else
     connection = giop_connection_list.fd_to_connection_mapping->pdata[i];
-    if (FD_ISSET(i, &giop_connection_list.selectset_rd)) {
+    if (FD_ISSET(i, &selectset_rd)) {
       goto got_connection;
     }
 #endif    
@@ -1341,7 +1372,7 @@ giop_check_connections(gboolean block_for_reply)
 	giop_main_handle_connection_exception(connection);
       }
 #else /* !USE_POLL */
-      if(FD_ISSET(i, &giop_connection_list.selectset_ex)) {
+      if(FD_ISSET(i, &selectset_ex)) {
 	connection = giop_connection_list.fd_to_connection_mapping->pdata[i];
 	giop_main_handle_connection_exception(connection);
       }
