@@ -469,7 +469,7 @@ ORBit_demarshal_allocate_mem(CORBA_TypeCode tc, gint nelements)
     return retval;
 }
 
-#define DM_GET_ATOM(x, n) G_STMT_START{ GIOP_RECV_BUFFER(buf)->decoder(x, (GIOP_RECV_BUFFER(buf)->cur), n); GIOP_RECV_BUFFER(buf)->cur = ((guchar *)GIOP_RECV_BUFFER(buf)) + n; }G_STMT_END
+#define DM_GET_ATOM(x, n) G_STMT_START{ GIOP_RECV_BUFFER(buf)->decoder(x, (GIOP_RECV_BUFFER(buf)->cur), n); GIOP_RECV_BUFFER(buf)->cur = ((guchar *)GIOP_RECV_BUFFER(buf)->cur) + n; }G_STMT_END
 
 static void
 ORBit_demarshal_value(GIOPRecvBuffer *buf,
@@ -678,8 +678,12 @@ ORBit_demarshal_any(GIOPRecvBuffer *buf, CORBA_any *retval,
 {
     gpointer val;
 
+#if 0
+    /* I wish I knew whether this was correct or not. It breaks things like 'any anop();' for sure,
+       since we can't always initialize every single possible 'any' underneath _ORBIT_retval */
     if(retval->_release)
 	CORBA_free(retval->_value);
+#endif
 
     CORBA_any_set_release(retval, CORBA_TRUE);
 
