@@ -89,7 +89,7 @@ CORBA_boolean CORBA_Object_is_a(CORBA_Object obj, CORBA_char *logical_type_id, C
 }
 
 /* Section 4.2.5 */
-CORBA_boolean CORBA_Object_non_existant(CORBA_Object obj, CORBA_Environment *ev)
+CORBA_boolean CORBA_Object_non_existent(CORBA_Object obj, CORBA_Environment *ev)
 {
 	g_assert(!"Not yet implemented");
 	return(CORBA_FALSE);
