@@ -415,6 +415,7 @@ ORBit_demarshal_object(GIOPRecvBuffer *recv_buffer, CORBA_ORB orb)
 
  error_exit:
 	ORBit_delete_profiles(profiles);
+
 	CORBA_exception_set_system(&ev, ex_CORBA_MARSHAL,
 				   CORBA_COMPLETED_MAYBE);
 	return CORBA_OBJECT_NIL;
@@ -679,3 +680,18 @@ void ORBit_object_locate(CORBA_Object obj, CORBA_Environment *ev)
 
 	giop_recv_buffer_unuse(recv_buffer);
 }
+
+GIOPConnection *
+ORBit_handle_location_forward(GIOPRecvBuffer *rb, CORBA_Object obj)
+{
+	GIOPConnection *retval;
+
+	if(obj->forward_locations)
+		ORBit_delete_profiles(obj->forward_locations);
+	obj->forward_locations = ORBit_demarshal_IOR(rb);
+
+	retval = ORBit_object_get_forwarded_connection(obj);
+	giop_recv_buffer_unuse(rb);
+
+	return retval;
+}
