@@ -469,6 +469,12 @@ ORBit_POA_handle_request(GIOPRecvBuffer *recv_buffer,
 
 	skel = ORBIT_OBJECT_KEY(servant->_private)->class_info->relay_call(servant, recv_buffer, &imp);
 
+	if(!skel) {
+		CORBA_exception_set_system(&ev, ex_CORBA_BAD_OPERATION,
+					   CORBA_COMPLETED_NO);
+		goto errout;
+	}
+
 	skel(servant, recv_buffer, &ev, imp);
 
 	if(poa->request_processing == PortableServer_USE_SERVANT_MANAGER) {
@@ -478,8 +484,25 @@ ORBit_POA_handle_request(GIOPRecvBuffer *recv_buffer,
 						       cookie, &ev);
 	}
 
+	return;
+
  errout:
-	/* XXX send an exception back */
+	if(ev._major == CORBA_SYSTEM_EXCEPTION) {
+		GIOPSendBuffer *reply_buf;
+
+		reply_buf =
+			giop_send_reply_buffer_use(GIOP_MESSAGE_BUFFER(recv_buffer)->connection,
+						   NULL,
+						   recv_buffer->message.u.request.request_id,
+						   CORBA_SYSTEM_EXCEPTION);
+
+		 ORBit_send_system_exception(reply_buf, &ev);
+
+		 giop_send_buffer_write(reply_buf);
+		 giop_send_buffer_unuse(reply_buf);
+	} else /* User exceptions are handled in the skels! */
+		g_assert(ev._major == CORBA_NO_EXCEPTION);
+
 	CORBA_exception_free(&ev);
 }
 
