@@ -162,7 +162,7 @@ void ORBit_decode_CORBA_TypeCode(CORBA_TypeCode* t, GIOPRecvBuffer* buf)
 	for(l=ctx.prior_tcs;l;l=l->next)
 		g_free(l->data);
 	g_slist_free(ctx.prior_tcs);
-	buf->cur = ((guchar *)buf) + codec->rptr;
+	buf->cur = ((guchar *)buf->cur) + codec->rptr;
 }
 	
 
