@@ -59,7 +59,7 @@ main (int argc, char *argv[])
 	      return 1;
 	    }
 
-	    g_assert(echo_client == bec);
+	    /* g_assert(echo_client == bec); */
 
 	    CORBA_Object_release(echo_client, &ev);
 	    if(ev._major != CORBA_NO_EXCEPTION) {
